@@ -23,7 +23,6 @@ class InternetDynamicFields(ProvisionDynamicFields):
             self._shipment_subdivision(),
             self._shipment_zip(),
             self._previous_owner_vat(),
-            self._notes(),
             self._adsl_coverage(),
             self._mm_fiber_coverage(),
             self._vdf_fiber_coverage(),
@@ -78,9 +77,6 @@ class InternetDynamicFields(ProvisionDynamicFields):
     def _previous_owner_vat(self):
         return DynamicField(name="NIFNIEtitular", value=self.service_data.previous_owner_vat)
 
-    def _notes(self):
-        return DynamicField(name="notes", value=self.service_data.notes)
-
     def _adsl_coverage(self):
         return DynamicField(name="coberturaADSL", value=self.service_data.adsl_coverage)
 
