@@ -45,10 +45,6 @@ class MobileProcessTicket:
         invoices_start_date = self.response.dynamic_field_get('dataIniciFacturacio').value
         return datetime.strptime(invoices_start_date, '%Y-%m-%d %H:%M:%S')
 
-    @property
-    def notes(self):
-        return self.response.dynamic_field_get('notes').value
-
     @property
     def service_technology(self):
         """ Return is the service is fiber or adsl """
