@@ -47,7 +47,7 @@ class ProvisionDynamicFields():
         return DynamicField(name="NIFNIESoci", value=self.customer_data.vat_number)
 
     def _mail(self):
-        return DynamicField(name="correuElectronic", value=self.customer_data.email)
+        return DynamicField(name="correuElectronic", value=self.service_data.email)
 
     def _phone(self):
         return DynamicField(name="telefonContacte", value=self.customer_data.phone)
