@@ -23,11 +23,11 @@ class ADSLDynamicFieldsTestCase(unittest.TestCase):
             'name',
             'vat_number',
             'phone',
-            'email',
         ])
         self.service_data = Mock(spec=[
             'order_id',
             'iban',
+            'email',
             'phone_number',
             'landline_phone_number',
             'service_address',
@@ -155,7 +155,7 @@ class ADSLDynamicFieldsTestCase(unittest.TestCase):
         self.assertEqual(dynamic_fields_dct["telefonContacte"], "666666666")
 
     def test_contact_email_field(self):
-        self.customer_data.email = "test@email.org"
+        self.service_data.email = "test@email.org"
 
         dynamic_fields = ADSLDynamicFields(
             self.service_data,
@@ -364,19 +364,6 @@ class ADSLDynamicFieldsTestCase(unittest.TestCase):
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
         self.assertEqual(dynamic_fields_dct["cognom1Titular"], "Surname")
 
-    def test_notes_field(self):
-        self.service_data.notes = "Note"
-
-        dynamic_fields = ADSLDynamicFields(
-            self.service_data,
-            self.customer_data,
-            self.adsl_otrs_process_id,
-            self.adsl_otrs_activity_id
-        ).all()
-
-        dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
-        self.assertEqual(dynamic_fields_dct["notes"], "Note")
-
     def test_adsl_coverage_field(self):
         self.service_data.adsl_coverage = "20"
 
