@@ -11,6 +11,7 @@ class FiberDataTestCase(unittest.TestCase):
             order_id=123,
             phone_number="666666666",
             iban="ES6621000418401234567891",
+            email="test@test.com",
             previous_provider="SC",
             previous_internal_provider=None,
             previous_owner_vat="740227654G",
@@ -31,7 +32,9 @@ class FiberDataTestCase(unittest.TestCase):
             mm_fiber_coverage=None,
             vdf_fiber_coverage=None,
             change_address="no",
-            product="product"
+            product="product",
+            old_contract_fiber_speed="100Mb",
+            old_contract_pon="VDF0001"
         )
 
         self.assertIsInstance(fiber_data, FiberData)
