@@ -18,9 +18,11 @@ class FiberTicketTestCase(unittest.TestCase):
             "Type": FiberTicketConfiguration.type,
             "Queue": FiberTicketConfiguration.queue,
             "State": FiberTicketConfiguration.state,
+            "SLA": FiberTicketConfiguration.SLA,
+            "Service": FiberTicketConfiguration.service,
             "Priority": FiberTicketConfiguration.priority,
             "CustomerUser": customer_data.id,
-            "CustomerID": customer_data.id
+            "CustomerID": customer_data.id,
         }
 
         FiberTicket(service_data, customer_data)._build_ticket()
@@ -29,13 +31,17 @@ class FiberTicketTestCase(unittest.TestCase):
     @patch('otrs_somconnexio.otrs_models.provision_ticket.ProvisionArticle')
     def test_build_article(self, MockInternetArticle):
         customer_data = Mock(spec=[])
-        service_data = Mock(spec=['order_id'])
+        service_data = Mock(spec=['order_id','notes'])
 
         mock_mobile_article = MockInternetArticle.return_value
 
         FiberTicket(service_data, customer_data)._build_article()
 
-        MockInternetArticle.assert_called_with('fiber', service_data.order_id)
+        MockInternetArticle.assert_called_with(
+            'fiber', 
+            service_data.order_id,
+            service_data.notes
+        )
         mock_mobile_article.call.assert_called_once()
 
     @patch('otrs_somconnexio.otrs_models.fiber_ticket.FiberDynamicFields')
@@ -59,7 +65,6 @@ class FiberTicketTestCase(unittest.TestCase):
     def test_create(self, MockOTRSClient):
         customer_data = Mock(spec=[
             'id',
-            'email',
             'phone',
             'first_name',
             'name',
@@ -67,7 +72,10 @@ class FiberTicketTestCase(unittest.TestCase):
         ])
         service_data = Mock(spec=[
             'order_id',
+            'old_contract_pon',
+            'old_contract_fiber_speed',
             'iban',
+            'email',
             'previous_service',
             'phone_number',
             'previous_provider',
@@ -104,3 +112,6 @@ class FiberTicketTestCase(unittest.TestCase):
 
         self.assertEqual(ticket.id, 123)
         self.assertEqual(ticket.number, '#123')
+        self.assertEqual(ticket.otrs_configuration.type, "Petición")
+        self.assertEqual(ticket.otrs_configuration.SLA, "No pendent resposta")
+        self.assertEqual(ticket.otrs_configuration.service, "Banda Ancha::Fibra::Provisió Fibra")
